@@ -145,8 +145,8 @@ board_register_kaggle <- function(name = "kaggle",
 #' board_register_rsconnect(account = "account-name")
 #'
 #' # register automated report for rstudio connect
-#' board_register_rsconnect(key = Sys.getenv("RSTUDIO_KEY"),
-#'                          server = "https://rstudio-connect-server")
+#' board_register_rsconnect(key = Sys.getenv("CONNECT_API_KEY"),
+#'                          server = Sys.getenv("CONNECT_SERVER"))
 #' }
 #'
 #' @export
@@ -285,6 +285,7 @@ board_register_azure <- function(name = "azure",
                  name = name,
                  account = account,
                  container = container,
+                 key = key,
                  cache = cache,
                  ...)
 }
