@@ -1,5 +1,16 @@
 context("board rsc")
 
+test_rsconnect_boards <- function(key, server) {
+  board_register("rsconnect",
+                 key = key,
+                 server = server,
+                 cache = tempfile())
+
+  board_test("rsconnect", destination = server)
+
+  board_deregister("rsconnect")
+}
+
 if (test_board_is_registered("rsconnect")) {
   board_test("rsconnect")
 } else {
@@ -11,14 +22,12 @@ if (test_board_is_registered("rsconnect")) {
     if (length(rsc_servers) != length(rsc_apis)) stop("Incorrect length for TEST_RSCONNECT_SERVER and RSCONNECT_API.")
 
     for (rsc_index in seq_along(rsc_servers)) {
-      board_register("rsconnect",
-                     key = rsc_apis[[rsc_index]],
-                     server = rsc_servers[[rsc_index]],
-                     cache = tempfile())
+      server <- gsub("/$", "", rsc_servers[[rsc_index]])
 
-      board_test("rsconnect", destination = paste0(rsc_servers[[rsc_index]]))
+      test_rsconnect_boards(rsc_apis[[rsc_index]], server)
 
-      board_deregister("rsconnect")
+      # also test with trailing slash
+      test_rsconnect_boards(rsc_apis[[rsc_index]], paste0(server, "/"))
     }
   } else {
     test_that("can't register rsconnect board", {
